@@ -37,8 +37,6 @@
  *
  * A single handle should not be used simultaneously from multiple threads.
  *
- * Currently Finnish is the only supported language.
- *
  */
 
 #ifndef VOIKKO_VOIKKO_H
@@ -59,9 +57,8 @@ struct VoikkoHandle;
  * to the standard dictionary search path.
  * @param error Will be set to null if initialization completed without error.
  *        Otherwise will be set to a pointer to a string describing the error.
- * @param langcode BCP 47 language tag for the language to be used. Currently this can
- *        only be Finnish with optional private use subtags to specify the dictionary
- *        variant.
+ * @param langcode BCP 47 language tag for the language to be used. Private use
+ *        subtags can be used to specify the dictionary variant.
  * @param path path to a directory from which dictionary files should be searched
  *        first before looking into the standard dictionary locations. If NULL, no
  *        additional search path will be used.
@@ -160,6 +157,19 @@ char * voikkoHyphenateCstr(struct VoikkoHandle * handle, const char * word);
  */
 char * voikkoHyphenateUcs4(struct VoikkoHandle * handle, const wchar_t * word);
 
+/**
+ * Hyphenates the given word in UTF-8 encoding.
+ * @param handle voikko instance
+ * @param word word to hyphenate
+ * @param hyphen character string to insert at hyphenation positions
+ * @param allowContextChanges boolean parameter that specifies wheter hyphens
+ *        may be inserted even if they alter the word in unhyphenated form.
+ * @return null terminated character string where hyphens are inserted in all
+ *         hyphenation points
+ */
+char * voikkoInsertHyphensCstr(struct VoikkoHandle * handle, const char * word,
+                               const char * hyphen, int allowContextChanges);
+
 /**
  * Frees the memory allocated for spelling suggestions.
  * @param suggest_result spelling suggestions
@@ -458,6 +468,16 @@ char * voikko_mor_analysis_value_cstr(
  */
 void voikko_free_mor_analysis_value_cstr(char * analysis_value);
 
+
+/**
+ * Get list of possible attribute values in morphological analysis.
+ * @param handle voikko instance
+ * @param attributeName name of morphological analysis attribute
+ * @return a list of possible attribute values for attribute in morphological analysis.
+ * If the attribute does not exist or it does not have a known finite set of possible values returns null.
+ */
+char ** voikkoGetAttributeValues(struct VoikkoHandle * handle, const char * attributeName);
+
 #ifndef VOIKKO_NO_DEPRECATED_API
 #include "voikko_deprecated.h"
 #endif
